@@ -1,4 +1,4 @@
-#define VERSION "1.0.8"
+#define VERSION "1.0.9"
 
 #define HAVE_STRING_H 1
 #define HAVE_STDLIB_H 1
@@ -15,7 +15,12 @@
 #define WITH_FLOAT 1
 
 #define snprintf _snprintf
+#define strcasecmp _stricmp
+
+#if _MSC_VER < 1500
 #define vsnprintf _vsnprintf
+#endif
+
 #define STDIN_FILENO 0
 #define STDOUT_FILENO 1
 #define STDERR_FILENO 2
@@ -26,6 +31,7 @@
 #pragma warning(disable : 4244)
 #pragma warning(disable : 4101)
 #pragma warning(disable : 4305)
+#pragma warning(disable : 4996)
 
 #define WITHOUT_SERVER 1
 
