@@ -37,6 +37,14 @@ typedef struct _fluid_audriver_definition_t
 } fluid_audriver_definition_t;
 
 
+#if PULSE_SUPPORT
+fluid_audio_driver_t* new_fluid_pulse_audio_driver(fluid_settings_t* settings,
+						   fluid_synth_t* synth);
+fluid_audio_driver_t* new_fluid_pulse_audio_driver2(fluid_settings_t* settings,
+						    fluid_audio_func_t func, void* data);
+int delete_fluid_pulse_audio_driver(fluid_audio_driver_t* p);
+void fluid_pulse_audio_driver_settings(fluid_settings_t* settings);
+#endif
 
 #if ALSA_SUPPORT
 fluid_audio_driver_t* new_fluid_alsa_audio_driver(fluid_settings_t* settings,
@@ -74,6 +82,7 @@ void fluid_dsound_audio_driver_settings(fluid_settings_t* settings);
 #endif
 
 #if PORTAUDIO_SUPPORT
+void fluid_portaudio_driver_settings (fluid_settings_t *settings);
 fluid_audio_driver_t* new_fluid_portaudio_driver(fluid_settings_t* settings,
 						 fluid_synth_t* synth);
 int delete_fluid_portaudio_driver(fluid_audio_driver_t* p);
@@ -96,6 +105,13 @@ fluid_audio_driver_t* new_fluid_sndmgr_audio_driver2(fluid_settings_t* settings,
 int delete_fluid_sndmgr_audio_driver(fluid_audio_driver_t* p);
 #endif
 
+#if DART_SUPPORT
+fluid_audio_driver_t* new_fluid_dart_audio_driver(fluid_settings_t* settings,
+                          fluid_synth_t* synth);
+int delete_fluid_dart_audio_driver(fluid_audio_driver_t* p);
+void fluid_dart_audio_driver_settings(fluid_settings_t* settings);
+#endif
+
 #define AUFILE_SUPPORT 1
 #if AUFILE_SUPPORT
 fluid_audio_driver_t* new_fluid_file_audio_driver(fluid_settings_t* settings,
@@ -104,13 +120,14 @@ int delete_fluid_file_audio_driver(fluid_audio_driver_t* p);
 void fluid_file_audio_driver_settings(fluid_settings_t* settings);
 #endif
 
+/* Available audio drivers, listed in order of preference */
 fluid_audriver_definition_t fluid_audio_drivers[] = {
-#if OSS_SUPPORT
-  { "oss",
-    new_fluid_oss_audio_driver,
-    new_fluid_oss_audio_driver2,
-    delete_fluid_oss_audio_driver,
-    fluid_oss_audio_driver_settings },
+#if JACK_SUPPORT
+  { "jack",
+    new_fluid_jack_audio_driver,
+    new_fluid_jack_audio_driver2,
+    delete_fluid_jack_audio_driver,
+    fluid_jack_audio_driver_settings },
 #endif
 #if ALSA_SUPPORT
   { "alsa",
@@ -119,6 +136,20 @@ fluid_audriver_definition_t fluid_audio_drivers[] = {
     delete_fluid_alsa_audio_driver,
     fluid_alsa_audio_driver_settings },
 #endif
+#if OSS_SUPPORT
+  { "oss",
+    new_fluid_oss_audio_driver,
+    new_fluid_oss_audio_driver2,
+    delete_fluid_oss_audio_driver,
+    fluid_oss_audio_driver_settings },
+#endif
+#if PULSE_SUPPORT
+  { "pulseaudio",
+    new_fluid_pulse_audio_driver,
+    new_fluid_pulse_audio_driver2,
+    delete_fluid_pulse_audio_driver,
+    fluid_pulse_audio_driver_settings },
+#endif
 #if COREAUDIO_SUPPORT
   { "coreaudio",
     new_fluid_core_audio_driver,
@@ -138,7 +169,7 @@ fluid_audriver_definition_t fluid_audio_drivers[] = {
     new_fluid_portaudio_driver,
     NULL,
     delete_fluid_portaudio_driver,
-    NULL },
+    fluid_portaudio_driver_settings },
 #endif
 #if SNDMAN_SUPPORT
   { "sndman",
@@ -147,12 +178,12 @@ fluid_audriver_definition_t fluid_audio_drivers[] = {
     delete_fluid_sndmgr_audio_driver,
     NULL },
 #endif
-#if JACK_SUPPORT
-  { "jack",
-    new_fluid_jack_audio_driver,
-    new_fluid_jack_audio_driver2,
-    delete_fluid_jack_audio_driver,
-    fluid_jack_audio_driver_settings },
+#if DART_SUPPORT
+  { "dart",
+    new_fluid_dart_audio_driver,
+    NULL,
+    delete_fluid_dart_audio_driver,
+    fluid_dart_audio_driver_settings },
 #endif
 #if AUFILE_SUPPORT
   { "file",
@@ -191,8 +222,12 @@ void fluid_audio_driver_settings(fluid_settings_t* settings)
 #endif
 
   /* Set the default driver */
-#if ALSA_SUPPORT
+#if JACK_SUPPORT
+  fluid_settings_register_str(settings, "audio.driver", "jack", 0, NULL, NULL);
+#elif ALSA_SUPPORT
   fluid_settings_register_str(settings, "audio.driver", "alsa", 0, NULL, NULL);
+#elif PULSE_SUPPORT
+  fluid_settings_register_str(settings, "audio.driver", "pulseaudio", 0, NULL, NULL);
 #elif OSS_SUPPORT
   fluid_settings_register_str(settings, "audio.driver", "oss", 0, NULL, NULL);
 #elif COREAUDIO_SUPPORT
@@ -203,8 +238,8 @@ void fluid_audio_driver_settings(fluid_settings_t* settings)
   fluid_settings_register_str(settings, "audio.driver", "sndman", 0, NULL, NULL);
 #elif PORTAUDIO_SUPPORT
   fluid_settings_register_str(settings, "audio.driver", "portaudio", 0, NULL, NULL);
-#elif JACK_SUPPORT
-  fluid_settings_register_str(settings, "audio.driver", "jack", 0, NULL, NULL);
+#elif DART_SUPPORT
+  fluid_settings_register_str(settings, "audio.driver", "dart", 0, NULL, NULL);
 #elif AUFILE_SUPPORT
   fluid_settings_register_str(settings, "audio.driver", "file", 0, NULL, NULL);
 #else
@@ -212,6 +247,9 @@ void fluid_audio_driver_settings(fluid_settings_t* settings)
 #endif
 
   /* Add all drivers to the list of options */
+#if PULSE_SUPPORT
+  fluid_settings_add_option(settings, "audio.driver", "pulseaudio");
+#endif
 #if ALSA_SUPPORT
   fluid_settings_add_option(settings, "audio.driver", "alsa");
 #endif
@@ -233,6 +271,9 @@ void fluid_audio_driver_settings(fluid_settings_t* settings)
 #if JACK_SUPPORT
   fluid_settings_add_option(settings, "audio.driver", "jack");
 #endif
+#if DART_SUPPORT
+  fluid_settings_add_option(settings, "audio.driver", "dart");
+#endif
 #if AUFILE_SUPPORT
   fluid_settings_add_option(settings, "audio.driver", "file");
 #endif
